# eoq3 - EOQ3 core implementation for python

This implements EOQ3 domains, values, queries and commands in python. 
It is the central module of the EOQ3 implementation for python. 
It contains a ready-to-use domainwithmdb for programatic model interactions.

## Getting started example 

   TODO

## Documentation

For more information see EOQ3 documentation: https://eoq.gitlab.io/doc/eoq3/

## pyeoq repository

All eoq3 python modules can be found here: https://gitlab.com/eoq/py/pyeoq

## Author

2024 Bjoern Annighoefer


